@@ -18,8 +18,8 @@
 #
 # Program: WorkerLocal.pm
 # Author:  Timo Benk <benk@b1-systems.de>
-# Date:    Tue Jun 18 14:32:15 2013 +0200
-# Ident:   c8aa7aa524efca900339f1fef0c19c2b1c5f8dc1
+# Date:    Wed May 8 13:46:36 2013 +0200
+# Ident:   31a16b3e65edd6e679b461c0e27ea92a8b373c24
 # Branch:  master
 #
 # Changelog:--reverse --grep '^tags.*relevant':-1:%an : %ai : %s
@@ -27,39 +27,25 @@
 # Timo Benk : 2013-04-28 17:27:31 +0200 : initial checkin
 # Timo Benk : 2013-04-29 18:53:21 +0200 : introducing ncopy
 # Timo Benk : 2013-05-08 09:55:24 +0200 : TARGET_HOST is now visible in ps output
-# Timo Benk : 2013-05-21 18:47:43 +0200 : parameter --async added
-# Timo Benk : 2013-05-23 17:26:57 +0200 : comment fixed for delete()
-# Timo Benk : 2013-05-24 08:03:19 +0200 : generic mode added
-# Timo Benk : 2013-06-13 13:59:01 +0200 : process output handling refined
-# Timo Benk : 2013-06-13 20:32:17 +0200 : using __PACKAGE__ is less error-prone
-# Timo Benk : 2013-06-14 12:53:08 +0200 : $_self->{O|E} must be used instead of STD{OUT|ERR}
 #
 
-###
-# this worker executes the given script locally and sets the environment
-# variable TARGET_HOST on each execution
-###
-
-package NRun::Worker::WorkerLocal;
+package WorkerLocal;
 
 use strict;
 use warnings;
 
 use File::Basename;
-
 use NRun::Worker;
 
 our @ISA = qw(NRun::Worker);
 
-BEGIN {
+###
+# module specification
+our $MODINFO = {
 
-    NRun::Worker::register ( {
-
-        'MODE' => "local",
-        'DESC' => "execute the script locally, set TARGET_HOST on each execution",
-        'NAME'   => __PACKAGE__,
-    } );
-}
+  'MODE' => "local",
+  'DESC' => "execute the script locally, set TARGET_HOST on each execution",
+};
 
 ###
 # create a new object.
@@ -68,82 +54,73 @@ BEGIN {
 sub new {
 
     my $_pkg = shift;
+    my $_obj = shift;
 
     my $self = {};
     bless $self, $_pkg;
 
+    $self->{MODINFO} = $MODINFO;
     return $self;
 }
 
-# initialize this worker module.
-#
-# $_cfg - parameter hash where
-# {
-#   'hostname'   - hostname this worker should act on
-#   'local_exec' - commandline for the exec command (COMMAND, ARGUMENTS, HOSTNAME will be replaced)
-# }
-sub init {
-
-    my $_self = shift;
-    my $_cfg  = shift;
-
-    $_self->SUPER::init($_cfg);
-
-    $_self->{local_exec}   = $_cfg->{local_exec};
-}
-
 ###
-# copy a file to $_self->{hostname}.
+# copy a file to $_host.
 #
+# $_host   - the host the command should be exeuted on
 # $_source - source file to be copied
 # $_target - destination $_source should be copied to
-# <- the return code
+# <- (
+#      $ret - the return code
+#      $out - command output
+#    )
 sub copy {
 
     my $_self   = shift;
+    my $_host   = shift;
     my $_source = shift;
     my $_target = shift;
 
-    print {$_self->{E}} "$_self->{hostname};stderr;" . time() . ";$$;n/a;error;\"not implemented\"\n";
-
-    return 1;
+    return (1, "not implemented");
 }
 
 ###
 # execute the command locally and set environment variable TARGET_HOST
-# to $_self->{hostname}.
+# to $_host.
 #
+# $_host    - the host the command should be exeuted on
 # $_command - the command that should be executed
 # $_args    - arguments that should be supplied to $_command
-# <- the return code
+# <- (
+#      $ret - the return code
+#      $out - command output
+#    )
 sub execute {
 
     my $_self    = shift;
+    my $_host    = shift;
     my $_command = shift;
     my $_args    = shift;
 
-    my $cmdline = $_self->{local_exec};
-
-    $cmdline =~ s/COMMAND/$_command/g;
-    $cmdline =~ s/ARGUMENTS/$_args/g;
-    $cmdline =~ s/HOSTNAME/$_self->{hostname}/g;
-
-    return $_self->do($cmdline);
+    return _("TARGET_HOST=$_host $_command $_args");
 }
 
 ###
-# delete a file on $_self->{hostname}.
+# delete a file on $_host.
 #
-# $_file - the file that should be deleted
-# <- the return code
+# $_host - the host the command should be exeuted on
+# $_file - the command that should be executed
+# <- (
+#      $ret - the return code
+#      $out - command output
+#    )
 sub delete {
 
     my $_self = shift;
+    my $_host = shift;
     my $_file = shift;
 
-    print {$_self->{E}} "$_self->{hostname};stderr;" . time() . ";$$;n/a;error;\"not implemented\"\n";
-
-    return 1;
+    return (1, "not implemented");
 }
 
 1;
+
