@@ -18,8 +18,8 @@
 #
 # Program: WorkerSsh.pm
 # Author:  Timo Benk <benk@b1-systems.de>
-# Date:    Tue Jun 18 14:32:15 2013 +0200
-# Ident:   c8aa7aa524efca900339f1fef0c19c2b1c5f8dc1
+# Date:    Wed May 8 13:46:36 2013 +0200
+# Ident:   31a16b3e65edd6e679b461c0e27ea92a8b373c24
 # Branch:  master
 #
 # Changelog:--reverse --grep '^tags.*relevant':-1:%an : %ai : %s
@@ -28,18 +28,9 @@
 # Timo Benk : 2013-04-28 20:02:52 +0200 : options --skip-ping-check and --skip-ns-check added
 # Timo Benk : 2013-04-28 22:01:00 +0200 : ping and ns check moved into Main::callback_action
 # Timo Benk : 2013-04-29 18:53:21 +0200 : introducing ncopy
-# Timo Benk : 2013-05-21 18:47:43 +0200 : parameter --async added
-# Timo Benk : 2013-05-23 17:26:57 +0200 : comment fixed for delete()
-# Timo Benk : 2013-05-24 08:03:19 +0200 : generic mode added
-# Timo Benk : 2013-06-13 13:59:01 +0200 : process output handling refined
-# Timo Benk : 2013-06-13 20:32:17 +0200 : using __PACKAGE__ is less error-prone
 #
 
-###
-# this worker implements ssh based remote execution
-###
-
-package NRun::Worker::WorkerSsh;
+package WorkerSsh;
 
 use strict;
 use warnings;
@@ -50,19 +41,26 @@ use POSIX qw(getuid);
 
 our @ISA = qw(NRun::Worker);
 
-BEGIN {
+###
+# module specification
+our $MODINFO = {
 
-    NRun::Worker::register ( {
-
-        'MODE' => "ssh",
-        'DESC' => "ssh based remote execution",
-        'NAME'   => __PACKAGE__,
-    } );
-}
+  'MODE' => "ssh",
+  'DESC' => "ssh based remote execution",
+};
 
 ###
 # create a new object.
 #
+# $_cfg - parameter hash where
+# {
+#   'ssh_args'   - arguments supplied to the ssh binary
+#   'scp_args'   - arguments supplied to the scp binary
+#   'ssh_binary' - ssh binary to be executed
+#   'scp_binary' - scp binary to be executed
+#   'ssh_user'   - ssh login user
+#   'scp_user'   - scp login user
+# }
 # <- the new object
 sub new {
 
@@ -72,89 +70,84 @@ sub new {
     my $self = {};
     bless $self, $_pkg;
 
+    $self->{ssh_args}   = $_cfg->{ssh_args};
+    $self->{scp_args}   = $_cfg->{scp_args};
+    $self->{ssh_binary} = $_cfg->{ssh_binary};
+    $self->{scp_binary} = $_cfg->{scp_binary};
+    $self->{ssh_user}   = $_cfg->{ssh_user};
+    $self->{scp_user}   = $_cfg->{scp_user};
+
+    if (not defined($self->{ssh_user})) {
+
+        ($self->{ssh_user}) = getpwuid(getuid());
+    }
+
+    if (not defined($self->{scp_user})) {
+
+        ($self->{scp_user}) = getpwuid(getuid());
+    }
+
+    $self->{MODINFO} = $MODINFO;
     return $self;
 }
 
 ###
-# initialize this worker module.
-#
-# $_cfg - parameter hash where
-# {
-#   'hostname'   - hostname this worker should act on
-#   'ssh_copy'   - commandline for the copy command (SOURCE, TARGET, HOSTNAME will be replaced)
-#   'ssh_exec'   - commandline for the exec command (COMMAND, ARGUMENTS, HOSTNAME will be replaced)
-#   'ssh_delete' - commandline for the delete command (FILE, HOSTNAME will be replaced)
-# }
-sub init {
-
-    my $_self = shift;
-    my $_cfg  = shift;
-
-    $_self->SUPER::init($_cfg);
-
-    $_self->{ssh_copy}   = $_cfg->{ssh_copy};
-    $_self->{ssh_exec}   = $_cfg->{ssh_exec};
-    $_self->{ssh_delete} = $_cfg->{ssh_delete};
-}
-
-###
-# copy a file to $_self->{hostname}.
+# copy a file using ssh to $_host.
 #
+# $_host   - the host the command should be exeuted on
 # $_source - source file to be copied
 # $_target - destination $_source should be copied to
-# <- the return code
+# <- (
+#      $ret - the return code 
+#      $out - command output
+#    )
 sub copy {
 
     my $_self   = shift;
+    my $_host   = shift;
     my $_source = shift;
     my $_target = shift;
 
-    my $cmdline = $_self->{ssh_copy};
-
-    $cmdline =~ s/SOURCE/$_source/g;
-    $cmdline =~ s/TARGET/$_target/g;
-    $cmdline =~ s/HOSTNAME/$_self->{hostname}/g;
-
-    return $_self->do($cmdline);
+    return _("$_self->{scp_binary} $_self->{scp_args} $_source $_self->{scp_user}\@$_host:$_target");
 }
 
 ###
-# execute the command on $_self->{hostname}.
+# execute the command using ssh on $_host.
 #
+# $_host    - the host the command should be exeuted on
 # $_command - the command that should be executed
 # $_args    - arguments that should be supplied to $_command
-# <- the return code
+# <- (
+#      $ret - the return code 
+#      $out - command output
+#    )
 sub execute {
 
     my $_self    = shift;
+    my $_host    = shift;
     my $_command = shift;
     my $_args    = shift;
 
-    my $cmdline = $_self->{ssh_exec};
-
-    $cmdline =~ s/COMMAND/$_command/g;
-    $cmdline =~ s/ARGUMENTS/$_args/g;
-    $cmdline =~ s/HOSTNAME/$_self->{hostname}/g;
-
-    return $_self->do($cmdline);
+    return _("$_self->{ssh_binary} $_self->{ssh_args} -l $_self->{ssh_user} $_host $_command $_args");
 }
 
 ###
-# delete a file on $_self->{hostname}.
+# delete a file using ssh on $_host.
 #
-# $_file - the file that should be deleted
-# <- the return code
+# $_host - the host the command should be exeuted on
+# $_file - the command that should be executed
+# <- (
+#      $ret - the return code 
+#      $out - command output
+#    )
 sub delete {
 
     my $_self = shift;
+    my $_host = shift;
     my $_file = shift;
 
-    my $cmdline = $_self->{ssh_delete};
-
-    $cmdline =~ s/FILE/$_file/g;
-    $cmdline =~ s/HOSTNAME/$_self->{hostname}/g;
-
-    return $_self->do($cmdline);
+    return _("$_self->{ssh_binary} $_self->{ssh_args} -l $_self->{ssh_user} $_host rm -f \"$_file\"");
 }
 
 1;
+
